View source: R/set_matomo_server.R
| set_matomo_server | R Documentation |
set_matomo_server This command is required to set the specifications to connect to the server
set_matomo_server(server = "webzh-dk", tokenString = NULL)
server |
A character vector specifying which server to access. Currently it supports the three possibilities openzh (the open data websites), webzh-dk (the data catalogue of webzh) and webzh (the websites of webzh). By default it will access webzh-dk if nothign was provided. |
tokenString |
A character vector specifying which token to access. It is an optional argument overriding the default strings. These are token_openzh, token_webzh-dk and token_webzh. |
The output is a connection object, that is actually a list object containing the three needed parameters to set up the connection.
conObj<-set_matomo_server(server="openzh")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.